@@ -356,7 +356,11 @@ logview_help (GtkAction *action, GtkWidget *parent_window)
 {
   GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+  gtk_show_uri_on_window (GTK_WINDOW (parent_window),
+#else
   gtk_show_uri (gtk_widget_get_screen (parent_window),
+#endif
                 "help:mate-system-log", gtk_get_current_event_time (),
                 &error);
 
@@ -766,8 +770,7 @@ logview_about (GtkWidget *widget, GtkWidget *window)
   gtk_show_about_dialog (GTK_WINDOW (window),
                          "name",  _("System Log Viewer"),
                          "version", VERSION,
-                         "copyright", "Copyright \xc2\xa9 1998-2008 Free Software Foundation, Inc.\n"
-                                      "Copyright \xc2\xa9 2011-2017 MATE developers",
+                         "copyright", "Copyright \xc2\xa9 1998-2008 Free Software Foundation, Inc.",
                          "license", license_trans,
                          "wrap-license", TRUE,
                          "comments", _("A system log viewer for MATE."),
