@@ -157,6 +157,7 @@ gdict_aligned_window_position (GdictAlignedWindow *window)
   GdictAlignedWindowPrivate *priv;
   GtkWidget *align_widget;
   gint our_width, our_height;
+  gint sc_width, sc_height;
   gint entry_x, entry_y, entry_width, entry_height;
   gint x, y;
   GdkGravity gravity = GDK_GRAVITY_NORTH_WEST;
@@ -189,7 +190,10 @@ gdict_aligned_window_position (GdictAlignedWindow *window)
   			 &entry_y);
   gdk_window_get_geometry (gdk_window, NULL, NULL, &entry_width, &entry_height);
 
-  if (entry_x + our_width < gdk_screen_width ())
+  gdk_window_get_geometry (gdk_screen_get_root_window (gdk_screen_get_default()),
+                           NULL, NULL, &sc_width, &sc_height);
+
+  if (entry_x + our_width < sc_width)
     x = entry_x + 1;
   else
     {
@@ -198,7 +202,7 @@ gdict_aligned_window_position (GdictAlignedWindow *window)
       gravity = GDK_GRAVITY_NORTH_EAST;
     }
   
-  if (entry_y + entry_height + our_height < gdk_screen_height ())
+  if (entry_y + entry_height + our_height < sc_height)
     y = entry_y + entry_height - 1;
   else
     {
