@@ -38,10 +38,6 @@
 #include "gdict-common.h"
 #include "gdict-aligned-window.h"
 
-#if !GTK_CHECK_VERSION(3,0,0)
-#define gtk_widget_get_preferred_size(x,y,z) gtk_widget_size_request(x,y)
-#endif
-
 #define GDICT_APPLET_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GDICT_TYPE_APPLET, GdictAppletClass))
 #define GDICT_APPLET_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GDICT_TYPE_APPLET, GdictAppletClass))
 
@@ -134,8 +130,13 @@ set_window_default_size (GdictApplet *applet)
   GtkWidget *widget, *defbox;
   gint width, height;
   gint font_size;
+#if GTK_CHECK_VERSION (3, 22, 0)
+  GdkDisplay *display;
+  GdkMonitor *monitor_num;
+#else
   GdkScreen *screen;
   gint monitor_num;
+#endif
   GtkRequisition req;
   GdkRectangle monitor;
 
@@ -158,11 +159,18 @@ set_window_default_size (GdictApplet *applet)
   height = MAX (height, req.height);
 
   /* ... but make it no larger than half the monitor size */
+#if GTK_CHECK_VERSION (3, 22, 0)
+  display = gtk_widget_get_display (widget);
+  monitor_num = gdk_display_get_monitor_at_window (display,
+                                                   gtk_widget_get_window (widget));
+  gdk_monitor_get_geometry (monitor_num, &monitor);
+#else
   screen = gtk_widget_get_screen (widget);
   monitor_num = gdk_screen_get_monitor_at_window (screen,
                                                   gtk_widget_get_window (widget));
 
   gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+#endif
 
   width = MIN (width, monitor.width / 2);
   height = MIN (height, monitor.height / 2);
@@ -338,11 +346,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (frame);
   priv->frame = frame;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
-#else
-  vbox = gtk_vbox_new (FALSE, 12);
-#endif
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
   gtk_container_add (GTK_CONTAINER (frame), vbox);
   gtk_widget_show (vbox);
@@ -356,11 +360,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_set_can_focus (priv->defbox, TRUE);
   gtk_widget_set_can_default (priv->defbox, TRUE);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
-#else
-  bbox = gtk_hbutton_box_new ();
-#endif
   gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
   gtk_box_set_spacing (GTK_BOX (bbox), 6);
   gtk_box_pack_end (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
@@ -520,22 +520,7 @@ gdict_applet_draw (GdictApplet *applet)
   if (priv->box)
     gtk_widget_destroy (priv->box);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   box = gtk_box_new (priv->orient, 0);
-#else
-  switch (priv->orient)
-    {
-    case GTK_ORIENTATION_VERTICAL:
-      box = gtk_vbox_new (FALSE, 0);
-      break;
-    case GTK_ORIENTATION_HORIZONTAL:
-      box = gtk_hbox_new (FALSE, 0);
-      break;
-    default:
-      g_assert_not_reached ();
-      break;
-    }
-#endif
   
   gtk_container_add (GTK_CONTAINER (applet), box);
   gtk_widget_show (box);
@@ -558,11 +543,7 @@ gdict_applet_draw (GdictApplet *applet)
   gtk_box_pack_start (GTK_BOX (box), priv->toggle, FALSE, FALSE, 0);
   gtk_widget_show (priv->toggle);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-  hbox = gtk_hbox_new (FALSE, 0);
-#endif
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
   gtk_container_add (GTK_CONTAINER (priv->toggle), hbox);
   gtk_widget_show (hbox);
@@ -748,7 +729,11 @@ gdict_applet_cmd_help (GtkAction *action,
 {
   GError *err = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+  gtk_show_uri_on_window (NULL,
+#else
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+#endif
 		"help:mate-dictionary/mate-dictionary-applet",
 		gtk_get_current_event_time (), &err);
   
