@@ -469,7 +469,11 @@ gdict_source_dialog_response_cb (GtkDialog *dialog,
       build_new_source (GDICT_SOURCE_DIALOG (dialog));
       break;
     case GTK_RESPONSE_HELP:
+#if GTK_CHECK_VERSION (3, 22, 0)
+      gtk_show_uri_on_window (GTK_WINDOW (dialog),
+#else
       gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+#endif
                     "help:mate-dictionary/mate-dictionary-add-source",
                     gtk_get_current_event_time (), &err);
       if (err)
@@ -582,10 +586,6 @@ gdict_source_dialog_constructor (GType                  type,
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
 
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_widget_push_composite_child ();
-#endif
-
   /* get the UI from the GtkBuilder file */
   dialog->builder = gtk_builder_new ();
   gtk_builder_add_from_file (dialog->builder, GDICT_SOURCE_UI, &error);
@@ -673,10 +673,6 @@ gdict_source_dialog_constructor (GType                  type,
    */
   update_dialog_ui (dialog);
 
-#if !GTK_CHECK_VERSION(3,0,0)
-  gtk_widget_pop_composite_child ();
-#endif
-
   return object;
 }
 
