@@ -93,6 +93,7 @@ static GdkPixbuf *screenshot = NULL;
 
 /* Global variables*/
 static char *last_save_dir = NULL;
+static char *window_title = NULL;
 static char *temporary_file = NULL;
 static gboolean save_immediately = FALSE;
 static GSettings *settings = NULL;
@@ -122,9 +123,16 @@ display_help (GtkWindow *parent)
 {
   GError *error = NULL;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+  gtk_show_uri_on_window (parent,
+                          "help:mate-user-guide/goseditmainmenu-53",
+                          gtk_get_current_event_time (),
+                          &error);
+#else
   gtk_show_uri (gtk_window_get_screen (parent),
 		"help:mate-user-guide/goseditmainmenu-53",
 		gtk_get_current_event_time (), &error);
+#endif
 
   if (error)
     {
@@ -1022,7 +1030,7 @@ out:
 }
 
 static GdkWindow *
-find_current_window (void)
+find_current_window (char **window_title)
 {
   GdkWindow *window;
 
@@ -1037,6 +1045,15 @@ find_current_window (void)
 	  take_window_shot = FALSE;
 	  window = gdk_get_default_root_window ();
 	}
+      else
+	{
+	  gchar *tmp, *sanitized;
+
+	  tmp = screenshot_get_window_title (window);
+	  sanitized = screenshot_sanitize_filename (tmp);
+	  g_free (tmp);
+	  *window_title = sanitized;
+	}
     }
   else
     {
@@ -1058,7 +1075,7 @@ push_check_file_job (GdkRectangle *rectangle)
   job->base_uris[2] = g_strconcat ("file://", g_get_tmp_dir (), NULL);
   job->iteration = 0;
   job->type = TEST_LAST_DIR;
-  job->window = find_current_window ();
+  job->window = find_current_window (&window_title);
 
   if (rectangle != NULL)
     {
