@@ -34,6 +34,55 @@ static GtkWidget *selection_window;
 
 #define SELECTION_NAME "_MATE_PANEL_SCREENSHOT"
 
+static char *
+get_utf8_property (GdkWindow *window,
+		   GdkAtom    atom)
+{
+  gboolean res;
+  GdkAtom utf8_string;
+  GdkAtom type;
+  int actual_format, actual_length;
+  guchar *data;
+  char *retval;
+
+  utf8_string = gdk_x11_xatom_to_atom (gdk_x11_get_xatom_by_name ("UTF8_STRING"));
+  res = gdk_property_get (window, atom, utf8_string,
+                          0, G_MAXLONG, FALSE,
+                          &type,
+                          &actual_format, &actual_length,
+                          &data);
+  if (!res)
+    return NULL;
+
+  if (type != utf8_string || actual_format != 8 || actual_length == 0)
+    {
+      g_free (data);
+      return NULL;
+    }
+
+  if (!g_utf8_validate ((gchar *) data, actual_length, NULL))
+    {
+      char *atom_name = gdk_atom_name (atom);
+
+      g_warning ("Property `%s' (format: %d, length: %d) contained "
+                 "invalid UTF-8",
+                 atom_name,
+                 actual_format,
+                 actual_length);
+
+      g_free (atom_name);
+      g_free (data);
+
+      return NULL;
+    }
+
+  retval = g_strndup ((gchar *) data, actual_length);
+
+  g_free (data);
+
+  return retval;
+}
+
 /* To make sure there is only one screenshot taken at a time,
  * (Imagine key repeat for the print screen key) we hold a selection
  * until we are done taking the screenshot
@@ -112,16 +161,90 @@ screenshot_window_is_desktop (GdkWindow *window)
 
 }
 
+#define MAXIMUM_WM_REPARENTING_DEPTH 4
+
+static GdkWindow *
+look_for_hint_helper (GdkWindow *window,
+		      GdkAtom    property,
+		      int       depth)
+{
+  gboolean res;
+  GdkAtom actual_type;
+  int actual_format, actual_length;
+  guchar *data;
+
+  res = gdk_property_get (window, property, GDK_NONE,
+                          0, 1, FALSE,
+                          &actual_type,
+                          &actual_format, &actual_length,
+                          &data);
+
+  if (res == TRUE &&
+      data != NULL &&
+      actual_format == 32 &&
+      data[0] == 1)
+    {
+      g_free (data);
+
+      return window;
+    }
+
+  if (depth < MAXIMUM_WM_REPARENTING_DEPTH)
+    {
+      GList *children, *l;
+
+      children = gdk_window_get_children (window);
+      if (children != NULL)
+        {
+          for (l = children; l; l = l->next)
+            {
+              window = look_for_hint_helper (l->data, property, depth + 1);
+              if (window)
+                break;
+            }
+
+          g_list_free (children);
+
+          if (window)
+            return window;
+        }
+    }
+
+  return NULL;
+}
+
+static GdkWindow *
+look_for_hint (GdkWindow *window,
+	       GdkAtom property)
+{
+  GdkWindow *retval;
+
+  retval = look_for_hint_helper (window, property, 0);
+
+  return retval;
+}
+
 GdkWindow *
 screenshot_find_current_window ()
 {
   GdkWindow *current_window;
+#if GTK_CHECK_VERSION (3, 20, 0)
+  GdkDisplay *display;
+  GdkSeat *seat;
+#else
   GdkDeviceManager *manager;
+#endif
   GdkDevice *device;
 
   current_window = screenshot_find_active_window ();
+#if GTK_CHECK_VERSION (3, 20, 0)
+  display = gdk_window_get_display (current_window);
+  seat = gdk_display_get_default_seat (display);
+  device = gdk_seat_get_pointer (seat);
+#else
   manager = gdk_display_get_device_manager (gdk_display_get_default ());
   device = gdk_device_manager_get_client_pointer (manager);
+#endif
 
   /* If there's no active window, we fall back to returning the
    * window that the cursor is in.
@@ -334,8 +457,12 @@ screenshot_select_area_async (SelectAreaCallback callback)
 {
   GdkDisplay *display;
   GdkCursor               *cursor;
+#if GTK_CHECK_VERSION (3, 20, 0)
+  GdkSeat *seat;
+#else
   GdkDeviceManager *manager;
   GdkDevice *pointer, *keyboard;
+#endif
   GdkGrabStatus res;
   select_area_filter_data  data;
   GdkRectangle *rectangle;
@@ -359,11 +486,32 @@ screenshot_select_area_async (SelectAreaCallback callback)
   display = gdk_display_get_default ();
   cursor = gdk_cursor_new_for_display (display, GDK_CROSSHAIR);
 
+#if GTK_CHECK_VERSION (3, 20, 0)
+  seat = gdk_display_get_default_seat (display);
+
+  res = gdk_seat_grab (seat,
+                       gtk_widget_get_window (data.window),
+                       GDK_SEAT_CAPABILITY_ALL,
+                       FALSE,
+                       cursor,
+                       NULL,
+                       NULL,
+                       NULL);
+
+  if (res != GDK_GRAB_SUCCESS)
+    {
+      g_object_unref (cursor);
+      goto out;
+    }
+
+  gtk_main ();
+
+  gdk_seat_ungrab (seat);
+#else
   manager = gdk_display_get_device_manager (display);
   pointer = gdk_device_manager_get_client_pointer (manager);
   keyboard = gdk_device_get_associated_device (pointer);
 
-
   res = gdk_device_grab (pointer, gtk_widget_get_window (data.window),
                          GDK_OWNERSHIP_NONE, FALSE,
                          GDK_POINTER_MOTION_MASK |
@@ -393,6 +541,7 @@ screenshot_select_area_async (SelectAreaCallback callback)
 
   gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
   gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
+#endif
 
   gtk_widget_destroy (data.window);
   g_object_unref (cursor);
@@ -434,11 +583,19 @@ find_wm_window (Window xid)
 static cairo_region_t *
 make_region_with_monitors (GdkScreen *screen)
 {
+#if GTK_CHECK_VERSION (3, 22, 0)
+  GdkDisplay     *display;
+#endif
   cairo_region_t *region;
   int num_monitors;
   int i;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+  display = gdk_screen_get_display (screen);
+  num_monitors = gdk_display_get_n_monitors (display);
+#else
   num_monitors = gdk_screen_get_n_monitors (screen);
+#endif
 
   region = cairo_region_create ();
 
@@ -446,7 +603,11 @@ make_region_with_monitors (GdkScreen *screen)
     {
       GdkRectangle rect;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+      gdk_monitor_get_geometry (gdk_display_get_monitor (display, i), &rect);
+#else
       gdk_screen_get_monitor_geometry (screen, i, &rect);
+#endif
       cairo_region_union_rectangle (region, &rect);
     }
 
@@ -542,8 +703,9 @@ mask_monitors (GdkPixbuf *pixbuf, GdkWindow *root_window)
 
   rect.x = 0;
   rect.y = 0;
-  rect.width = gdk_screen_get_width (screen);
-  rect.height = gdk_screen_get_height (screen);
+
+  gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+                           &rect.width, &rect.height);
 
   invisible_region = cairo_region_create_rectangle (&rect);
   cairo_region_subtract (invisible_region, region_with_monitors);
@@ -565,6 +727,10 @@ screenshot_get_pixbuf (GdkWindow    *window,
   GdkPixbuf *screenshot;
   gint x_real_orig, y_real_orig, x_orig, y_orig;
   gint width, real_width, height, real_height;
+  gint sc_width, sc_height;
+
+  gdk_window_get_geometry (gdk_screen_get_root_window (gdk_screen_get_default()),
+                           NULL, NULL, &sc_width, &sc_height);
 
   /* If the screenshot should include the border, we look for the WM window. */
 
@@ -605,11 +771,11 @@ screenshot_get_pixbuf (GdkWindow    *window,
       y_orig = 0;
     }
 
-  if (x_orig + width > gdk_screen_width ())
-    width = gdk_screen_width () - x_orig;
+  if (x_orig + width > sc_width)
+    width = sc_width - x_orig;
 
-  if (y_orig + height > gdk_screen_height ())
-    height = gdk_screen_height () - y_orig;
+  if (y_orig + height > sc_height)
+    height = sc_height - y_orig;
 
   if (rectangle)
     {
@@ -677,11 +843,11 @@ screenshot_get_pixbuf (GdkWindow    *window,
                   rec_height += y_real_orig;
                 }
 
-              if (x_orig + rec_x + rec_width > gdk_screen_width ())
-                rec_width = gdk_screen_width () - x_orig - rec_x;
+              if (x_orig + rec_x + rec_width > sc_width)
+                rec_width = sc_width - x_orig - rec_x;
 
-              if (y_orig + rec_y + rec_height > gdk_screen_height ())
-                rec_height = gdk_screen_height () - y_orig - rec_y;
+              if (y_orig + rec_y + rec_height > sc_height)
+                rec_height = sc_height - y_orig - rec_y;
 
               for (y = rec_y; y < rec_y + rec_height; y++)
                 {
@@ -727,13 +893,24 @@ screenshot_get_pixbuf (GdkWindow    *window,
 
       if (cursor_pixbuf != NULL)
         {
+#if GTK_CHECK_VERSION (3, 20, 0)
+          GdkDisplay *display;
+          GdkSeat *seat;
+#else
           GdkDeviceManager *manager;
+#endif
           GdkDevice *device;
           GdkRectangle r1, r2;
           gint cx, cy, xhot, yhot;
 
+#if GTK_CHECK_VERSION (3, 20, 0)
+          display = gdk_window_get_display (window);
+          seat = gdk_display_get_default_seat (display);
+          device = gdk_seat_get_pointer (seat);
+#else
           manager = gdk_display_get_device_manager (gdk_display_get_default ());
           device = gdk_device_manager_get_client_pointer (manager);
+#endif
           gdk_window_get_device_position (window, device, &cx, &cy, NULL);
           sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "x_hot"), "%d", &xhot);
           sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "y_hot"), "%d", &yhot);
@@ -770,6 +947,23 @@ screenshot_get_pixbuf (GdkWindow    *window,
   return screenshot;
 }
 
+gchar *
+screenshot_get_window_title (GdkWindow *win)
+{
+  gchar *name;
+
+  win = gdk_window_get_toplevel (win);
+  win = look_for_hint (win, gdk_x11_xatom_to_atom (gdk_x11_get_xatom_by_name ("WM_STATE")));
+
+  name = get_utf8_property (win, gdk_x11_xatom_to_atom (gdk_x11_get_xatom_by_name ("_NET_WM_NAME")));
+  if (name)
+    return name;
+
+  /* TODO: maybe we should also look at WM_NAME and WM_CLASS? */
+
+  return g_strdup (_("Untitled Window"));
+}
+
 void
 screenshot_show_error_dialog (GtkWindow   *parent,
                               const gchar *message,
